@@ -139,7 +139,8 @@ s3deploy.BucketDeployment(self, "DeployMeWithoutDeletingFilesOnDestination",
 )
 ```
 
-This option also enables you to specify multiple bucket deployments for the same destination bucket & prefix,
+This option also enables you to
+multiple bucket deployments for the same destination bucket & prefix,
 each with its own characteristics. For example, you can set different cache-control headers
 based on file extensions:
 
@@ -263,14 +264,19 @@ s3deploy.BucketDeployment(self, "DeployWithInvalidation",
 )
 ```
 
-## Memory Limit
+## Size Limits
 
 The default memory limit for the deployment resource is 128MiB. If you need to
-copy larger files, you can use the `memoryLimit` configuration to specify the
+copy larger files, you can use the `memoryLimit` configuration to increase the
 size of the AWS Lambda resource handler.
 
-> NOTE: a new AWS Lambda handler will be created in your stack for each memory
-> limit configuration.
+The default ephemeral storage size for the deployment resource is 512MiB. If you
+need to upload larger files, you may hit this limit. You can use the
+`ephemeralStorageSize` configuration to increase the storage size of the AWS Lambda
+resource handler.
+
+> NOTE: a new AWS Lambda handler will be created in your stack for each combination
+> of memory and storage size.
 
 ## EFS Support
 
@@ -421,6 +427,7 @@ class BucketDeployment(
         destination_key_prefix: typing.Optional[builtins.str] = None,
         distribution: typing.Optional[aws_cdk.aws_cloudfront.IDistribution] = None,
         distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+        ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         expires: typing.Optional[aws_cdk.core.Expiration] = None,
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -453,6 +460,7 @@ class BucketDeployment(
         :param destination_key_prefix: Key prefix in the destination bucket. Must be <=104 characters Default: "/" (unzip to root of the destination bucket)
         :param distribution: The CloudFront distribution using the destination bucket as an origin. Files in the distribution's edge caches will be invalidated after files are uploaded to the destination bucket. Default: - No invalidation occurs
         :param distribution_paths: The file paths to invalidate in the CloudFront distribution. Default: - All files under the destination bucket key prefix will be invalidated.
+        :param ephemeral_storage_size: The size of the AWS Lambda function’s /tmp directory in MiB. Default: 512 MiB
         :param exclude: If this is set, matching files or objects will be excluded from the deployment's sync command. This can be used to exclude a file from being pruned in the destination bucket. If you want to just exclude files from the deployment package (which excludes these files evaluated when invalidating the asset), you should leverage the ``exclude`` property of ``AssetOptions`` when defining your source. Default: - No exclude filters are used
         :param expires: System-defined expires metadata to be set on all objects in the deployment. Default: - The objects in the distribution will not expire.
         :param include: If this is set, matching files or objects will be included with the deployment's sync command. Since all files from the deployment package are included by default, this property is usually leveraged alongside an ``exclude`` filter. Default: - No include filters are used and all files are included with the sync command
@@ -483,6 +491,7 @@ class BucketDeployment(
             destination_key_prefix=destination_key_prefix,
             distribution=distribution,
             distribution_paths=distribution_paths,
+            ephemeral_storage_size=ephemeral_storage_size,
             exclude=exclude,
             expires=expires,
             include=include,
@@ -533,6 +542,7 @@ class BucketDeployment(
         "destination_key_prefix": "destinationKeyPrefix",
         "distribution": "distribution",
         "distribution_paths": "distributionPaths",
+        "ephemeral_storage_size": "ephemeralStorageSize",
         "exclude": "exclude",
         "expires": "expires",
         "include": "include",
@@ -567,6 +577,7 @@ class BucketDeploymentProps:
         destination_key_prefix: typing.Optional[builtins.str] = None,
         distribution: typing.Optional[aws_cdk.aws_cloudfront.IDistribution] = None,
         distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+        ephemeral_storage_size: typing.Optional[aws_cdk.core.Size] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         expires: typing.Optional[aws_cdk.core.Expiration] = None,
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -598,6 +609,7 @@ class BucketDeploymentProps:
         :param destination_key_prefix: Key prefix in the destination bucket. Must be <=104 characters Default: "/" (unzip to root of the destination bucket)
         :param distribution: The CloudFront distribution using the destination bucket as an origin. Files in the distribution's edge caches will be invalidated after files are uploaded to the destination bucket. Default: - No invalidation occurs
         :param distribution_paths: The file paths to invalidate in the CloudFront distribution. Default: - All files under the destination bucket key prefix will be invalidated.
+        :param ephemeral_storage_size: The size of the AWS Lambda function’s /tmp directory in MiB. Default: 512 MiB
         :param exclude: If this is set, matching files or objects will be excluded from the deployment's sync command. This can be used to exclude a file from being pruned in the destination bucket. If you want to just exclude files from the deployment package (which excludes these files evaluated when invalidating the asset), you should leverage the ``exclude`` property of ``AssetOptions`` when defining your source. Default: - No exclude filters are used
         :param expires: System-defined expires metadata to be set on all objects in the deployment. Default: - The objects in the distribution will not expire.
         :param include: If this is set, matching files or objects will be included with the deployment's sync command. Since all files from the deployment package are included by default, this property is usually leveraged alongside an ``exclude`` filter. Default: - No include filters are used and all files are included with the sync command
@@ -659,6 +671,8 @@ class BucketDeploymentProps:
             self._values["distribution"] = distribution
         if distribution_paths is not None:
             self._values["distribution_paths"] = distribution_paths
+        if ephemeral_storage_size is not None:
+            self._values["ephemeral_storage_size"] = ephemeral_storage_size
         if exclude is not None:
             self._values["exclude"] = exclude
         if expires is not None:
@@ -806,6 +820,15 @@ class BucketDeploymentProps:
         result = self._values.get("distribution_paths")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def ephemeral_storage_size(self) -> typing.Optional[aws_cdk.core.Size]:
+        '''The size of the AWS Lambda function’s /tmp directory in MiB.
+
+        :default: 512 MiB
+        '''
+        result = self._values.get("ephemeral_storage_size")
+        return typing.cast(typing.Optional[aws_cdk.core.Size], result)
+
     @builtins.property
     def exclude(self) -> typing.Optional[typing.List[builtins.str]]:
         '''If this is set, matching files or objects will be excluded from the deployment's sync command.
